summaryrefslogtreecommitdiff
path: root/chart2/source/controller/dialogs/tp_DataSource.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'chart2/source/controller/dialogs/tp_DataSource.hxx')
-rw-r--r--chart2/source/controller/dialogs/tp_DataSource.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/chart2/source/controller/dialogs/tp_DataSource.hxx b/chart2/source/controller/dialogs/tp_DataSource.hxx
index 291e3719a9a0..f606e9899e66 100644
--- a/chart2/source/controller/dialogs/tp_DataSource.hxx
+++ b/chart2/source/controller/dialogs/tp_DataSource.hxx
@@ -125,12 +125,12 @@ protected:
::com::sun::star::uno::Reference< ::com::sun::star::sheet::XRangeSelectionListener >
getSelectionRangeListener();
- /** @return </TRUE>, if the edit field contains a valid range entry. if no
- XCellRangesAccess can be obtained, </TRUE> is returned.
+ /** @return </sal_True>, if the edit field contains a valid range entry. if no
+ XCellRangesAccess can be obtained, </sal_True> is returned.
*/
bool isRangeFieldContentValid( Edit & rEdit );
/** @return </TRUE>, if the tab-page is in a consistent (commitable) state
*/
bool isValid();
void setDirty();
@@ -125,12 +125,12 @@ protected:
*/
bool isRangeFieldContentValid( Edit & rEdit );
- /** @return </TRUE>, if the tab-page is in a consistent (commitable) state
+ /** @return </sal_True>, if the tab-page is in a consistent (commitable) state
*/
bool isValid();